# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'gui_report.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(1035, 184)
        self.report_table = QtWidgets.QTableWidget(Form)
        self.report_table.setGeometry(QtCore.QRect(0, 50, 1031, 131))
        self.report_table.setObjectName("report_table")
        self.report_table.setColumnCount(0)
        self.report_table.setRowCount(0)
        self.report_title = QtWidgets.QLabel(Form)
        self.report_title.setGeometry(QtCore.QRect(10, 0, 1021, 41))
        font = QtGui.QFont()
        font.setFamily("Yu Gothic UI Semibold")
        font.setPointSize(28)
        font.setBold(True)
        font.setWeight(75)
        self.report_title.setFont(font)
        self.report_title.setObjectName("report_title")

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.report_title.setText(_translate("Form", "TextLabel"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())
